[dcms-cvs] cvs commit: pcms/src/common util.c

Jonathan S. Shapiro shap@hudson.cs.jhu.edu
Thu, 6 Dec 2001 14:49:38 -0500


shap        01/12/06 14:49:38

  Modified:    src      globals.h
               src/repos/common Repository.h
               src/repos/fs FileRepos.c
               src/common util.c
  Log:
  Rename serverURI to repositoryURI

Revision  Changes    Path
1.16      +2 -2      pcms/src/globals.h

Index: Repository.h
===================================================================
RCS file: /users/bigdisk/cvs/pcms/src/repos/common/Repository.h,v
retrieving revision 1.10
retrieving revision 1.11
diff -u -r1.10 -r1.11
--- Repository.h	2001/12/06 00:32:58	1.10
+++ Repository.h	2001/12/06 19:49:31	1.11
@@ -112,6 +112,3 @@
 extern void cachedfilerepository_init(Repository *);
 extern void netrepository_init(Repository *);
 
-/* COMMANDS ON REPOSITORIES */
-extern void pcms_create_repository(Repository *, int argc, char **argv);
-



1.13      +1 -1      pcms/src/repos/fs/FileRepos.c

Index: FileRepos.c
===================================================================
RCS file: /users/bigdisk/cvs/pcms/src/repos/fs/FileRepos.c,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -r1.12 -r1.13
--- FileRepos.c	2001/12/06 04:38:57	1.12
+++ FileRepos.c	2001/12/06 19:49:37	1.13
@@ -21,7 +21,7 @@
  ****/
 
   if (r == 0)
-      uri = uri_create(ServerURI);
+      uri = uri_create(RepositoryURI);
   else
       uri = r->uri;
 



1.4       +1 -1      pcms/src/common/util.c

Index: util.c
===================================================================
RCS file: /users/bigdisk/cvs/pcms/src/common/util.c,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- util.c	2001/11/08 23:11:52	1.3
+++ util.c	2001/12/06 19:49:37	1.4
@@ -1,6 +1,6 @@
 #include <pcms.h>
 
-char *ServerURI = 0;
+char *RepositoryURI = 0;
 
 int
 validate_pet_name(const char *s)
Index: globals.h
===================================================================
RCS file: /users/bigdisk/cvs/pcms/src/globals.h,v
retrieving revision 1.15
retrieving revision 1.16
diff -u -r1.15 -r1.16
--- globals.h	2001/12/04 15:02:38	1.15
+++ globals.h	2001/12/06 19:49:23	1.16
@@ -47,8 +47,8 @@
  * all of the calls to strcmp(): */
 int nmequal(const char *s1, const char *s2);
 
-/* Server URI to connect to: */
-extern char *ServerURI;
+/* Repository URI to connect to: */
+extern char *RepositoryURI;
 
 /* User's preferred editor: */
 extern char *Editor;



1.11      +0 -3      pcms/src/repos/common/Repository.h
